@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: bifunctors
-version: 5.2.1
-id: bifunctors-5.2.1-3dea194c07c9b02982b78a82398333cc
-key: bifun_2t2qRIffaTj78px8UA9i8X
+version: 5.3
+id: bifunctors-5.3-b98299755d5303d55588251f793bb639
+key: bifun_Lg5j6GeboyY0mvJdfqrKtl
 license: BSD3
 copyright: Copyright (C) 2008-2016 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -23,12 +23,13 @@ exposed-modules:
     Data.Bifunctor.TH Data.Bifunctor.Wrapped Data.Bitraversable
 hidden-modules: Data.Bifunctor.TH.Internal Paths_bifunctors
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/bifunctors-5.2.1
-library-dirs: /usr/lib/ghc-7.10.3/site-local/bifunctors-5.2.1
-data-dir: /usr/share/arm-linux-ghc-7.10.3/bifunctors-5.2.1
-hs-libraries: HSbifunctors-5.2.1-2t2qRIffaTj78px8UA9i8X
+import-dirs: /usr/lib/ghc-7.10.3/site-local/bifunctors-5.3
+library-dirs: /usr/lib/ghc-7.10.3/site-local/bifunctors-5.3
+data-dir: /usr/share/arm-linux-ghc-7.10.3/bifunctors-5.3
+hs-libraries: HSbifunctors-5.3-Lg5j6GeboyY0mvJdfqrKtl
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
+    base-orphans-0.5.3-27215a9428d23686c8514fbd3bba8ccb
     comonad-5-e98e7adc8875accf64a86529d9aeae51
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
